weaviate

package
v5.7.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: BSD-3-Clause Imports: 25 Imported by: 49

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client implementing the weaviate API Every function represents one API group of weaviate and provides a set of functions and builders to interact with them.

The client uses the original data models as provided by weaviate itself. All these models are provided in the sub module "github.com/weaviate/weaviate/entities/models"

func New

func New(config Config) *Client

New client from config Deprecated: Use NewClient() instead, which returns an error instead of panicking

func NewClient

func NewClient(config Config) (*Client, error)

func (*Client) Alias added in v5.3.0

func (c *Client) Alias() *alias.API

Alias API group

func (*Client) Backup

func (c *Client) Backup() *backup.API

Backup API group

func (*Client) Batch

func (c *Client) Batch() *batch.API

Batch loading API group

func (*Client) C11y

func (c *Client) C11y() *contextionary.API

C11y (contextionary) API group

func (*Client) Classifications

func (c *Client) Classifications() *classifications.API

Classifications API group

func (*Client) Cluster

func (c *Client) Cluster() *cluster.API

Cluster API group

func (*Client) Data

func (c *Client) Data() *data.API

Data API group including both things and actions

func (*Client) Experimental added in v5.4.0

func (c *Client) Experimental() *experimental

Experimental API group

func (*Client) GraphQL

func (c *Client) GraphQL() *graphql.API

GraphQL API group

func (*Client) Groups added in v5.5.0

func (c *Client) Groups() *groups.API

func (*Client) Misc

func (c *Client) Misc() *misc.API

Misc collection group for .well_known and root level API commands

func (*Client) Roles

func (c *Client) Roles() *rbac.API

func (*Client) Schema

func (c *Client) Schema() *schema.API

Schema API group

func (*Client) Tokenize added in v5.7.3

func (c *Client) Tokenize() *tokenize.API

Tokenize API group — /v1/tokenize (requires Weaviate >= 1.37.0).

func (*Client) Users

func (c *Client) Users() *users.API

func (*Client) WaitForWeavaite deprecated

func (c *Client) WaitForWeavaite(startupTimeout time.Duration) error

Waits for Weaviate to start.

Deprecated: "Weavaite" is a typo, prefer [WaitForWeaviate] instead.

func (*Client) WaitForWeaviate added in v5.7.1

func (c *Client) WaitForWeaviate(startupTimeout time.Duration) error

Waits for Weaviate to start.

type Config

type Config struct {
	// Host of the weaviate instance; this is a mandatory field.
	Host string
	// Scheme of the weaviate instance; this is a mandatory field.
	Scheme string

	// ConnectionClient that will be used to execute http requests to the weaviate instance.
	//  If omitted a default will be used. The default is not able to handle authenticated requests.
	//
	//  To connect with an authenticated weaviate consider using the client from the golang.org/x/oauth2 module.
	// Either this option or AuthConfig can be used
	ConnectionClient *http.Client

	// Configuration for authentication. Either this option or ConnectionClient can be used
	AuthConfig auth.Config

	// Headers added for every request
	Headers map[string]string

	// How long the client should wait for Weaviate to start up
	StartupTimeout time.Duration

	// gRPC configuration
	GrpcConfig *grpc.Config

	// Client connection timeout, defaults to 60s
	Timeout time.Duration
}

Config of the client endpoint

func NewConfig deprecated

func NewConfig(host string, scheme string, authConfig auth.Config,
	headers map[string]string, grpcConfig ...*grpc.Config,
) (*Config, error)

Deprecated: This function is unable to wait for Weaviate to start. Use NewClient() instead and add auth.Config to weaviate.Config

Directories

Path Synopsis
Package tokenize provides access to Weaviate's /v1/tokenize REST endpoints (available in Weaviate >= 1.37.0).
Package tokenize provides access to Weaviate's /v1/tokenize REST endpoints (available in Weaviate >= 1.37.0).

Jump to