Documentation
¶
Index ¶
- type Client
- func (c *Client) Alias() *alias.API
- func (c *Client) Backup() *backup.API
- func (c *Client) Batch() *batch.API
- func (c *Client) C11y() *contextionary.API
- func (c *Client) Classifications() *classifications.API
- func (c *Client) Cluster() *cluster.API
- func (c *Client) Data() *data.API
- func (c *Client) Experimental() *experimental
- func (c *Client) GraphQL() *graphql.API
- func (c *Client) Groups() *groups.API
- func (c *Client) Misc() *misc.API
- func (c *Client) Roles() *rbac.API
- func (c *Client) Schema() *schema.API
- func (c *Client) Tokenize() *tokenize.API
- func (c *Client) Users() *users.API
- func (c *Client) WaitForWeavaite(startupTimeout time.Duration) errordeprecated
- func (c *Client) WaitForWeaviate(startupTimeout time.Duration) error
- type Config
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client implementing the weaviate API Every function represents one API group of weaviate and provides a set of functions and builders to interact with them.
The client uses the original data models as provided by weaviate itself. All these models are provided in the sub module "github.com/weaviate/weaviate/entities/models"
func New ¶
New client from config Deprecated: Use NewClient() instead, which returns an error instead of panicking
func (*Client) Classifications ¶
func (c *Client) Classifications() *classifications.API
Classifications API group
func (*Client) Experimental ¶ added in v5.4.0
func (c *Client) Experimental() *experimental
Experimental API group
func (*Client) Tokenize ¶ added in v5.7.3
Tokenize API group — /v1/tokenize (requires Weaviate >= 1.37.0).
func (*Client) WaitForWeavaite
deprecated
type Config ¶
type Config struct {
// Host of the weaviate instance; this is a mandatory field.
Host string
// Scheme of the weaviate instance; this is a mandatory field.
Scheme string
// ConnectionClient that will be used to execute http requests to the weaviate instance.
// If omitted a default will be used. The default is not able to handle authenticated requests.
//
// To connect with an authenticated weaviate consider using the client from the golang.org/x/oauth2 module.
// Either this option or AuthConfig can be used
ConnectionClient *http.Client
// Configuration for authentication. Either this option or ConnectionClient can be used
AuthConfig auth.Config
// Headers added for every request
Headers map[string]string
// How long the client should wait for Weaviate to start up
StartupTimeout time.Duration
// gRPC configuration
GrpcConfig *grpc.Config
// Client connection timeout, defaults to 60s
Timeout time.Duration
}
Config of the client endpoint
Directories
¶
| Path | Synopsis |
|---|---|
|
Package tokenize provides access to Weaviate's /v1/tokenize REST endpoints (available in Weaviate >= 1.37.0).
|
Package tokenize provides access to Weaviate's /v1/tokenize REST endpoints (available in Weaviate >= 1.37.0). |
Click to show internal directories.
Click to hide internal directories.